"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var chai_1 = require("chai");
var docgenConverter_1 = require("../docgenConverter");
describe('docgenConverter', function () {
    it('Should work with class Component', function () {
        var result = docgenConverter_1.convertToDocgen({
            components: [
                {
                    name: 'name1',
                    comment: 'comment1',
                    extends: 'Component',
                    propInterface: {
                        name: 'PropsInterface',
                        comment: 'props comment',
                        members: [{
                                name: 'prop1',
                                comment: 'prop1 comment',
                                isRequired: true,
                                type: 'prop1 type'
                            }]
                    },
                }
            ]
        });
        chai_1.assert.isNotNull(result);
        chai_1.assert.equal('name1', result.displayName);
        chai_1.assert.equal('comment1', result.description);
        var prop1Result = result.props['prop1'];
        chai_1.assert.equal('prop1 type', prop1Result.type.name);
        chai_1.assert.equal('prop1 comment', prop1Result.description);
        chai_1.assert.equal(true, prop1Result.required);
    });
    it('Should work with functional StatelessComponent', function () {
        var result = docgenConverter_1.convertToDocgen({
            components: [
                {
                    name: 'name1',
                    comment: 'comment1',
                    extends: 'StatelessComponent',
                    propInterface: {
                        name: 'PropsInterface',
                        comment: 'props comment',
                        members: [{
                                name: 'prop1',
                                comment: 'prop1 comment',
                                isRequired: true,
                                type: 'prop1 type'
                            }]
                    }
                }
            ]
        });
        chai_1.assert.equal('name1', result.displayName);
        chai_1.assert.equal('comment1', result.description);
        var prop1Result = result.props['prop1'];
        chai_1.assert.equal('prop1 type', prop1Result.type.name);
        chai_1.assert.equal('prop1 comment', prop1Result.description);
        chai_1.assert.equal(true, prop1Result.required);
    });
    it('Should work without props interface', function () {
        var result = null;
        var originalWarn = console.warn;
        var warnCallCount = 0;
        console.warn = function () { return warnCallCount++; };
        try {
            result = docgenConverter_1.convertToDocgen({
                components: [
                    {
                        name: 'name1',
                        comment: 'comment1',
                        extends: 'Component',
                        propInterface: null,
                    }
                ]
            });
        }
        finally {
            console.warn = originalWarn;
        }
        chai_1.assert.equal(1, warnCallCount);
        chai_1.assert.equal('name1', result.displayName);
        chai_1.assert.equal('comment1', result.description);
    });
    it('Should work with class PureComponent', function () {
        var result = null;
        var originalWarn = console.warn;
        var warnCallCount = 0;
        console.warn = function () { return warnCallCount++; };
        try {
            result = docgenConverter_1.convertToDocgen({
                components: [
                    {
                        name: 'name1',
                        comment: 'comment1',
                        extends: 'PureComponent',
                        propInterface: null,
                    }
                ]
            });
        }
        finally {
            console.warn = originalWarn;
        }
        chai_1.assert.equal(1, warnCallCount);
        chai_1.assert.equal('name1', result.displayName);
        chai_1.assert.equal('comment1', result.description);
    });
});
//# sourceMappingURL=docgenConverter.spec.js.map